summaryrefslogtreecommitdiff
path: root/python/datarender.py
diff options
context:
space:
mode:
authorJordan Wiens <jordan@psifertex.com>2019-01-03 15:33:39 -0500
committerJordan Wiens <jordan@psifertex.com>2019-01-03 15:33:39 -0500
commit34b04f487e0dfcdc8766cb265e10dd3f58217f30 (patch)
tree6ccc49becfb5802bf982c9dc9978631283bc6c57 /python/datarender.py
parentac204fce33045803f27b438a2ffd3930d96fc52b (diff)
lots of spelling / typo fixes
Diffstat (limited to 'python/datarender.py')
-rw-r--r--python/datarender.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/python/datarender.py b/python/datarender.py
index c0a1dd3b..8b349fe1 100644
--- a/python/datarender.py
+++ b/python/datarender.py
@@ -34,18 +34,18 @@ from binaryninja import highlight
class DataRenderer(object):
"""
DataRender objects tell the Linear View how to render specific types.
The `perform_is_valid_for_data` method returns a boolean to indicate if your derrived class
is able to render the type, given the `addr` and `context`. The `context` is a list of Type
objects which represents the chain of nested objects that is being displayed.
The `perform_get_lines_for_data` method returns a list of `DisassemblyTextLine` objects each one
representing a single line of Linear View output. The `prefix` variable is a list of `InstructionTextToken`'s
- which have already been generated by other `DataRender`'s.
+ which have already been generated by other `DataRenderer`'s.
After defining the `DataRenderer` subclass you must then register it with the core. This is done by calling
- either `register_type_sepcific` or `register_generic`. A "generic" type renderer is able to be overridden by
+ either `register_type_specific` or `register_generic`. A "generic" type renderer is able to be overridden by
a "type specific" renderer. For instance there is a generic struct render which renders any struct that hasn't
been explicitly overridden by a "type specific" renderer.
@@ -65,7 +65,7 @@ class DataRenderer(object):
def __del__(self):
pass
- BarDataRenderer().register_type_sepcific()
+ BarDataRenderer().register_type_specific()
"""
def __init__(self, context=None):
self._cb = core.BNCustomDataRenderer()
@@ -81,7 +81,7 @@ class DataRenderer(object):
and context[0].type_class == TypeClass.NamedTypeReferenceClass and
context[0].named_type_reference.name == name)
- def register_type_sepcific(self):
+ def register_type_specific(self):
core.BNRegisterTypeSpecificDataRenderer(core.BNGetDataRendererContainer(), self.handle)
def register_generic(self):
@@ -34,18 +34,18 @@ from binaryninja import highlight
class DataRenderer(object):
"""
- DataRender objects tell the Linear View how to render specific types.
+ DataRenderer objects tell the Linear View how to render specific types.
- The `perform_is_valid_for_data` method returns a boolean to indicate if your derrived class
+ The `perform_is_valid_for_data` method returns a boolean to indicate if your derived class
is able to render the type, given the `addr` and `context`. The `context` is a list of Type
objects which represents the chain of nested objects that is being displayed.